import squint.*;
import javax.swing.*;
import java.net.*;

public class PanelessSMTPClient extends GUIManager {
    // The size of the program's window
    private final int WINDOW_WIDTH  = 450;
    private final int WINDOW_HEIGHT = 500;
   
    // amount of space to allow in a text field for an email address
    private final int ADDR_WIDTH = 14;
   
    // amount of space to allow in a text field for message subject
    private final int SUBJECT_WIDTH = 30;
   
    // how many characters wide program's text areas should be
    private final int AREA_WIDTH = 35;
   
    // how many lines tall the message area should be
    private final int MESSAGE_LINES = 12;
   
    // how many lines tall the log area should be
    private final int LOG_LINES = 8;

    // address of SMTP server to use
    private final String SMTP_SERVER = "cs.williams.edu";
   
    // Standard port for connection to an SMTP server
    private final int SMTP_PORT = 25;

    // Fields from to and from addresses, and the subject
    private JTextField from;
    private JTextField to;
    private JTextField subject;
   
    // Area in which user can type message body
    private JTextArea message;
   
    // Area in which responses from server will be logged
    private JTextArea log;
   
    // Our connection to the server
    NetConnection toServer;
   
    // Place fields and text areas on screen to enable user to
    // enter mail together with a send button.
    public PanelessSMTPClient() {
        // Create window to hold all the components
        this.createWindow( WINDOW_WIDTH, WINDOW_HEIGHT );
      
        contentPane.add( new JLabel( "To:" ) );
        to = new JTextField( ADDR_WIDTH );
        contentPane.add( to );
      
        contentPane.add( new JLabel( "From:" ) );
        from = new JTextField( ADDR_WIDTH );
        contentPane.add( from );

        contentPane.add( new JLabel( "Subject:" ) );
        subject = new JTextField( SUBJECT_WIDTH );
        contentPane.add( subject );
      
        contentPane.add ( new JLabel( "Enter your message below") );
      
        message = new JTextArea( MESSAGE_LINES, AREA_WIDTH );
        contentPane.add( new JScrollPane( message ) );
      
        contentPane.add( new JButton( "Send" ) );
      
        log = new JTextArea( LOG_LINES, AREA_WIDTH );
        contentPane.add( new JScrollPane( log ) );
        log.setEditable( false );
    }

    // Send message to server when user clicks "SEND"
    public void buttonClicked(  ) {
        // Establish a connection
        toServer = new NetConnection( SMTP_SERVER, SMTP_PORT );
        toServer.addMessageListener( this );
        toServer.out.println( "HELO " + this.getHostName() );
       
        // Send to and from addresses
        toServer.out.println( "MAIL FROM: <" + from.getText() +">" );
        toServer.out.println( "RCPT TO: <" + to.getText() +">" );
        
        // Send the message contents
        toServer.out.println( "DATA" );
        toServer.out.println( "Subject: " + subject.getText() );
        toServer.out.println( message.getText() );
        toServer.out.println( "." );
        
        // Say Goodnight Gracie
        toServer.out.println( "QUIT" );
    }
    
    // Display all message received from the server in the log area
    public void dataAvailable() {
        log.append( toServer.in.nextLine() + "\n" );
    }
    
    // Close our end of the connection when server responds to QUIT command
    public void connectionClosed() {
        toServer.close();
    }
}
