
import squint.*;
import javax.swing.*;

/*
 * Class WHOISClient - Request and display information about a
 *                     domain name from a WHOIS server
 */
public class WHOISClient extends GUIManager
{
   // Change these values to adjust the size of the program's window
   private final int WINDOW_WIDTH = 600, WINDOW_HEIGHT = 600;
   
   // Width of the area used to enter queries
   private final int QUERY_WIDTH = 20;
   
   // Dimensions of area used to display results
   private final int RESULTS_WIDTH = 40, RESULTS_HEIGHT = 20;
   
   // A reliable WHOIS server
   private final String serverName = "dns411.com";

   // Standard port for connection to a WHOIS server
   private final int WHOIS_PORT = 43;

   // The name to request information about
   private JTextField query;
   
   // Used to display the information requested
   private JTextArea results;
   
   // The connection to the server
   private NetConnection toServer;
   
   /*
    *  Display a field to hold the name to look up, a button,
    *  and a text area;
    */
    public WHOISClient() {
      // Create window to hold all the components
      this.createWindow( WINDOW_WIDTH, WINDOW_HEIGHT );
   
      JPanel queryPane = new JPanel();
      queryPane.add( new JLabel( "Name to look up:" ) );
      query = new JTextField( QUERY_WIDTH );
      queryPane.add( query );
      contentPane.add( queryPane );
      
      contentPane.add( new JButton( "Request Info" ) );
      
      results = new JTextArea( RESULTS_HEIGHT, RESULTS_WIDTH );
      contentPane.add( new JScrollPane( results ) );
    }

   /*
    *  Request and display information from the WHOIS server
    */
    public void buttonClicked( ) {
        toServer = new NetConnection( serverName, WHOIS_PORT );
        toServer.addMessageListener( this );
        toServer.out.println( query.getText() );
        results.setText( "" );
    }
    
    public void dataAvailable( ) {
        results.append( toServer.in.nextLine() + "\n" );        
    }
}
